@@ -28,16 +28,16 @@ class GabbleAccountUi : public AbstractAccountUi
     Q_OBJECT
 
 public:
-    explicit GabbleAccountUi(const QString &serviceName, QObject *parent = 0);
-    virtual ~GabbleAccountUi();
+    explicit GabbleAccountUi(const QString &serviceName, QObject *parent = nullptr);
+    ~GabbleAccountUi() override;
 
-    virtual AbstractAccountParametersWidget
+    AbstractAccountParametersWidget
               *mainOptionsWidget(ParameterEditModel *model,
-                                 QWidget *parent = 0) const override;
-    virtual bool hasAdvancedOptionsWidget() const override;
-    virtual AbstractAccountParametersWidget
+                                 QWidget *parent = nullptr) const override;
+    bool hasAdvancedOptionsWidget() const override;
+    AbstractAccountParametersWidget
               *advancedOptionsWidget(ParameterEditModel *model,
-                                     QWidget *parent = 0) const override;
+                                     QWidget *parent = nullptr) const override;
 
 private:
     Q_DISABLE_COPY(GabbleAccountUi)
