@@ -31,10 +31,10 @@ class MainOptionsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit MainOptionsWidget(ParameterEditModel *model,
-                               QWidget *parent = 0);
-    virtual ~MainOptionsWidget();
+                               QWidget *parent = nullptr);
+    ~MainOptionsWidget() override;
 
-    virtual QString defaultDisplayName() const override;
+    QString defaultDisplayName() const override;
 private:
     Q_DISABLE_COPY(MainOptionsWidget)
     Ui::MainOptionsWidget *m_ui;
