@@ -30,8 +30,8 @@ class SkypeAdvancedSettingsWidget : public AbstractAccountParametersWidget
     Q_OBJECT
 
 public:
-    explicit SkypeAdvancedSettingsWidget(ParameterEditModel *model, QWidget *parent = 0);
-    virtual ~SkypeAdvancedSettingsWidget();
+    explicit SkypeAdvancedSettingsWidget(ParameterEditModel *model, QWidget *parent = nullptr);
+    ~SkypeAdvancedSettingsWidget() override;
 
 private:
     Q_DISABLE_COPY(SkypeAdvancedSettingsWidget)
