@@ -31,9 +31,9 @@ class SunshineAccountUiPlugin : public AbstractAccountUiPlugin
 
 public:
     SunshineAccountUiPlugin(QObject *parent, const QVariantList &);
-    virtual ~SunshineAccountUiPlugin();
+    ~SunshineAccountUiPlugin() override;
 
-    virtual AbstractAccountUi* accountUi(const QString &connectionManager,
+    AbstractAccountUi* accountUi(const QString &connectionManager,
                                          const QString &protocol,
                                          const QString &serviceName) override;
 
