@@ -31,10 +31,10 @@ class SunshineMainOptionsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit SunshineMainOptionsWidget(ParameterEditModel *model,
-                                    QWidget *parent = 0);
-    virtual ~SunshineMainOptionsWidget();
+                                    QWidget *parent = nullptr);
+    ~SunshineMainOptionsWidget() override;
 
-    virtual QString defaultDisplayName() const override;
+    QString defaultDisplayName() const override;
 private:
     Q_DISABLE_COPY(SunshineMainOptionsWidget)
     Ui::SunshineMainOptionsWidget *m_ui;
